@@ -123,6 +123,9 @@ class TString :
     def ConvertToCTypeStrng(x) :
         return x.encode('utf-8')
 
+    def ConvertCTypeStringToUnicode(x) :
+        return x.decode('utf-8')
+
     
 #
 # enu class TDevType
@@ -157,6 +160,8 @@ class TDevice :
         T4 = enum.auto()
         T5 = enum.auto()
 
+    class ErrorString(enum.Enum) :
+        GetResp="ErrorGetResp"
     
     def __init__(this, deviceType):
         #print(DisplayName +"TRY: create " + deviceType.name )
@@ -223,6 +228,18 @@ class TDevice :
             bflag = False;
         return bflag
 
+    def SendTxtCmdReadResp(this, cmd, maxRespByteSize) :
+        respBytesArray=bytes(maxRespByteSize)
+        ret = TDevice_SendTxtCmd(this.__DeviceHandle, TString.ConvertToCTypeStrng(cmd), respBytesArray, maxRespByteSize, 1000)
+        if ret==0 :
+            bflag = True
+            resp = TString.ConvertCTypeStringToUnicode(respBytesArray)
+        else :
+            bflag = False;
+            resp = TDevice.ErrorString.GetResp
+        return resp
+
+
     #private methond
     def __SendCtrlCmd(this, cmd) :  
         ret = TDevice_SendCtrlCmd(this.__DeviceHandle, TString.ConvertToCTypeStrng(cmd), c_char_p(0), 0, 0)
